'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var rxjs = require('rxjs');
var operators = require('rxjs/operators');

/**
 * Returns an Observable for the endpoint staten
 */

var createObservableEndpoint = function createObservableEndpoint(endpoint, keys) {
  return new rxjs.Observable(function (observer) {
    var endpointPromise;
    var lastResult;
    observer.next({
      busy: true,
      value: undefined,
      state: 'LOADING',
      hasData: false
    });
    return endpoint.observePromise(keys, function () {
      if (lastResult) {
        observer.next({
          busy: true,
          value: lastResult,
          state: 'UPDATING',
          hasData: true
        });
      }

      var currentPromise = endpoint(keys);
      endpointPromise = currentPromise;
      endpointPromise.then(function (result) {
        if (currentPromise !== endpointPromise) {
          return;
        }

        lastResult = result;
        observer.next({
          busy: false,
          value: result,
          state: 'DONE',
          hasData: true
        });
      })["catch"](function () {
        if (currentPromise !== endpointPromise) {
          return;
        }

        lastResult = undefined;
        observer.next({
          busy: false,
          value: undefined,
          state: 'ERROR',
          hasData: false
        });
        return currentPromise;
      });
    });
  });
};
/**
 * Returns an Observable for the endpoint result
 */

function createObservableEndpointResponse(endpoint, keys) {
  return createObservableEndpoint(endpoint, keys).pipe(operators.tap(function (state) {
    if (state.state === 'ERROR') throw new Error();
  }), operators.filter(function (state) {
    return state.state === 'DONE';
  }), operators.map(function (state) {
    return state.value;
  }));
}

exports.createObservableEndpoint = createObservableEndpoint;
exports.createObservableEndpointResponse = createObservableEndpointResponse;
//# sourceMappingURL=request-registry-rxjs.cjs.development.js.map
