import { Observable } from 'rxjs';
import { tap, filter, map } from 'rxjs/operators';

/**
 * Returns an Observable for the endpoint staten
 */

var createObservableEndpoint = function createObservableEndpoint(endpoint, keys) {
  return new Observable(function (observer) {
    var endpointPromise;
    var lastResult;
    observer.next({
      busy: true,
      value: undefined,
      state: 'LOADING',
      hasData: false
    });
    return endpoint.observePromise(keys, function () {
      if (lastResult) {
        observer.next({
          busy: true,
          value: lastResult,
          state: 'UPDATING',
          hasData: true
        });
      }

      var currentPromise = endpoint(keys);
      endpointPromise = currentPromise;
      endpointPromise.then(function (result) {
        if (currentPromise !== endpointPromise) {
          return;
        }

        lastResult = result;
        observer.next({
          busy: false,
          value: result,
          state: 'DONE',
          hasData: true
        });
      })["catch"](function () {
        if (currentPromise !== endpointPromise) {
          return;
        }

        lastResult = undefined;
        observer.next({
          busy: false,
          value: undefined,
          state: 'ERROR',
          hasData: false
        });
        return currentPromise;
      });
    });
  });
};
/**
 * Returns an Observable for the endpoint result
 */

function createObservableEndpointResponse(endpoint, keys) {
  return createObservableEndpoint(endpoint, keys).pipe(tap(function (state) {
    if (state.state === 'ERROR') throw new Error();
  }), filter(function (state) {
    return state.state === 'DONE';
  }), map(function (state) {
    return state.value;
  }));
}

export { createObservableEndpoint, createObservableEndpointResponse };
//# sourceMappingURL=request-registry-rxjs.esm.js.map
